@@ -8,7 +8,7 @@
 #=========================================================#
 package Nile::Paginate;
 
-our $VERSION = '0.65';
+our $VERSION = '0.66';
 
 # pagination - pag·i·na·tion
 #1. the process of numbering the pages of a book.
@@ -866,6 +866,11 @@ sub showing_list {
     return $self->{showing_list};
 }
 #=========================================================#
+sub object {
+	my $self = shift;
+	$self->me->object(__PACKAGE__, @_);
+}
+#=========================================================#
 
 =head1 Bugs
 
