@@ -8,7 +8,7 @@
 #=========================================================#
 package Nile::Var;
 
-our $VERSION = '0.16';
+our $VERSION = '0.19';
 
 =pod
 
@@ -218,6 +218,11 @@ sub delete {
 	delete $self->{vars}->{$_} for @n;
 }
 #=========================================================#
+sub object {
+	my $self = shift;
+	$self->me->object(__PACKAGE__, @_);
+}
+#=========================================================#
 sub DESTROY {
 }
 #=========================================================#
