@@ -8,7 +8,7 @@
 #=========================================================#
 package Nile::View;
 
-our $VERSION = '0.15';
+our $VERSION = '0.19';
 
 =pod
 
@@ -1029,6 +1029,20 @@ sub header {
 	$self;
 }
 #=========================================================#
+=head2 object()
+	
+	# get a new view object
+	#my $view1 = $view->object;
+	
+Returns a new view object.
+
+=cut
+
+sub object {
+	my $self = shift;
+	$self->me->object(__PACKAGE__, @_);
+}
+#=========================================================#
 sub DESTROY {
 }
 #=========================================================#
